OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Zu den Favoriten hinzugefügt",
    "Removed from favorites" : "Aus den Favoriten entfernt",
    "You added {file} to your favorites" : "Sie haben {file} zu Ihren Favoriten hinzugefügt",
    "You removed {file} from your favorites" : "Sie haben {file} aus Ihren Favoriten entfernt",
    "Favorites" : "Favoriten",
    "File changes" : "Dateiänderungen",
    "Created by {user}" : "Erstellt durch {user}",
    "Changed by {user}" : "Geändert durch {user}",
    "Deleted by {user}" : "Gelöscht durch {user}",
    "Restored by {user}" : "Wiederhergestellt durch {user}",
    "Renamed by {user}" : "Umbenannt durch {user}",
    "Moved by {user}" : "Verschoben durch {user}",
    "\"remote account\"" : "\"Entferntes Konto\"",
    "You created {file}" : "Sie haben {file} erstellt",
    "You created an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} erstellt",
    "{user} created {file}" : "{user} hat {file} erstellt",
    "{user} created an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} erstellt",
    "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
    "You changed {file}" : "Sie haben {file} geändert",
    "You changed an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} geändert",
    "{user} changed {file}" : "{user} hat {file} geändert",
    "{user} changed an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} geändert",
    "You deleted {file}" : "Sie haben {file} gelöscht",
    "You deleted an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} gelöscht",
    "{user} deleted {file}" : "{user} hat {file} gelöscht",
    "{user} deleted an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} gelöscht",
    "You restored {file}" : "Sie haben {file} wiederhergestellt",
    "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Sie haben {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} (hidden) to {newfile}" : "Sie haben {oldfile} (versteckt) in {newfile} umbenannt",
    "You renamed {oldfile} to {newfile} (hidden)" : "Sie haben {oldfile} in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} to {newfile}" : "Sie haben {oldfile} in {newfile} umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hat {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hat {oldfile} (versteckt) in {newfile} umbenannt",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hat {oldfile} in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} to {newfile}" : "{user} hat {oldfile} in {newfile} umbenannt",
    "You moved {oldfile} to {newfile}" : "Sie haben {oldfile} nach {newfile} verschoben",
    "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde Ihren <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
    "Files" : "Dateien",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
    "Failed to authorize" : "Autorisierung fehlgeschlagen",
    "Invalid folder path" : "Ungültiger Ordner-Pfad",
    "Folder not found" : "Ordner nicht gefunden",
    "The file cannot be found" : "Die Datei kann nicht gefunden werden",
    "The destination path does not exist: %1$s" : "Der Zielpfad existiert nicht: %1$s",
    "You do not have permission to create a file at the specified location" : "Sie haben nicht die Berechtigung, eine Datei am angegebenen Speicherort zu erstellen",
    "The file could not be converted." : "Die Datei konnte nicht konvertiert werden.",
    "Could not get relative path to converted file" : "Relativer Pfad zur konvertierten Datei konnte nicht ermittelt werden",
    "Limit must be a positive integer." : "Der Grenzwert muss eine positive Ganzzahl sein.",
    "The replacement character may only be a single character." : "Das Ersatzzeichen darf nur ein einzelnes Zeichen sein.",
    "Filename sanitization already started." : "Die Dateinamenbereinigung hat bereits begonnen.",
    "No filename sanitization in progress." : "Es läuft keine Dateinamenbereinigung.",
    "Favorite files" : "Favorisierte Dateien",
    "No favorites" : "Keine Favoriten",
    "More favorites" : "Weitere Favoriten",
    "Accept" : "Akzeptieren",
    "Reject" : "Ablehnen",
    "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
    "Ownership transfer denied" : "Besitzübertragung abgelehnt",
    "Your ownership transfer of {path} was denied by {user}." : "Die Besitzübertragung von {path} wurde von {user} abgelehnt.",
    "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
    "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
    "The ownership transfer of {path} from {user} failed." : "Die Besitzübertragung von {path} vom Benutzer {user} ist fehlgeschlagen.",
    "Ownership transfer done" : "Besitzübertragung abgeschlossen",
    "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
    "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
    "in %s" : "in %s",
    "Transferred from %1$s on %2$s" : "Übertragen von %1$s an %2$s",
    "File Management" : "Dateiverwaltung",
    "Home" : "Home",
    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
    "Reload current directory" : "Aktuelles Verzeichnis neu laden",
    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}\" wechseln",
    "Current directory path" : "Aktueller Verzeichnispfad",
    "Share" : "Teilen",
    "Reload content" : "Inhalt erneut laden",
    "Your have used your space quota and cannot upload files anymore" : "Ihr Speicherplatzkontigent ist aufgebraucht, Sie können keine weiteren Dateien hochladen",
    "You do not have permission to upload or create files here." : "Sie haben nicht die Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
    "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
    "Favorite" : "Favorit",
    "Back" : "Zurück",
    "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
    "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
    "File is loading" : "Datei wird geladen",
    "Folder is loading" : "Ordner wird geladen",
    "Filename" : "Dateiname",
    "Folder name" : "Ordnername",
    "This node is unavailable" : "Dieser Knoten ist nicht verfügbar",
    "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
    "Invalid filename." : "Ungültiger Dateiname.",
    "Rename file" : "Datei umbenennen",
    "Folder" : "Ordner",
    "Unknown file type" : "Unbekannter Dateityp",
    "{ext} image" : "{ext}-Bild",
    "{ext} video" : "{ext}-Video",
    "{ext} audio" : "{ext}-Audio",
    "{ext} text" : "{ext}-Text",
    "Pending" : "Ausstehend",
    "Unknown date" : "Unbekanntes Datum",
    "Active filters" : "Aktive Filter",
    "Remove filter" : "Filter entfernen",
    "Today" : "Heute",
    "Last 7 days" : "Die letzten 7 Tage",
    "Last 30 days" : "Die letzten 30 Tage",
    "This year ({year})" : "Dieses Jahr ({year})",
    "Last year ({year})" : "Letztes Jahr ({year})",
    "Custom range" : "Benutzerdefinierter Bereich",
    "Custom date range" : "Benutzerdefinierter Zeitbereich",
    "Search everywhere" : "Überall suchen",
    "Documents" : "Dokumente",
    "Spreadsheets" : "Tabellenkalkulationen",
    "Presentations" : "Präsentationen",
    "PDFs" : "PDFs",
    "Folders" : "Ordner",
    "Audio" : "Audio",
    "Images" : "Bilder",
    "Videos" : "Videos",
    "Filters" : "Filter",
    "Back to filters" : "Zurück zu den Filtern",
    "Appearance" : "Aussehen",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "Show file type column" : "Dateityp-Spalte anzeigen",
    "Show file extensions" : "Dateierweiterungen anzeigen",
    "Crop image previews" : "Bildvorschauen zuschneiden",
    "General" : "Allgemein",
    "Sort favorites first" : "Favoriten zuerst sortieren",
    "Sort folders before files" : "Ordner vor Dateien sortieren",
    "Enable folder tree view" : "Ordnerbaumansicht aktivieren",
    "Default view" : "Standardansicht",
    "All files" : "Alle Dateien",
    "Personal files" : "Persönliche Dateien",
    "Additional settings" : "Zusätzliche Einstellungen",
    "Actions" : "Aktionen",
    "File actions" : "Dateiaktionen",
    "Selection" : "Auswahl",
    "Select all files" : "Alle Dateien auswählen",
    "Deselect all" : "Auswahl aufheben",
    "Select or deselect" : "Aus- oder abwählen",
    "Select a range" : "Einen Bereich auswählen",
    "Navigation" : "Navigation",
    "Go to parent folder" : "Zum übergeordneten Ordner wechseln",
    "Go to file above" : "Zur Datei darüber wechseln",
    "Go to file below" : "Zur Datei darunter wechseln",
    "Go left in grid" : "Im Raster nach links gehen",
    "Go right in grid" : "Im Raster nach rechts gehen",
    "View" : "Ansicht",
    "Toggle grid view" : "Kachelansicht umschalten",
    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
    "Warnings" : "Warnungen",
    "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
    "Warn before deleting a file" : "Warnung vor dem Löschen einer Datei",
    "WebDAV URL" : "WebDAV-URL",
    "Create an app password" : "Ein App-Passwort erstellen",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Erforderlich für die WebDAV-Authentifizierung, da für dieses Konto die Zwei-Faktor-Authentifizierung aktiviert ist.",
    "How to access files using WebDAV" : "So greifen Sie mit WebDAV auf Dateien zu",
    "Total rows summary" : "Zusammenfassung aller Zeilen",
    "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
    "Name" : "Name",
    "File type" : "Dateityp",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "{displayName}: failed on some elements" : "{displayName}: Ist bei einigen Elementen fehlgeschlagen",
    "{displayName}: done" : "{displayName}: Abgeschlossen",
    "{displayName}: failed" : "{displayName}: Fehlgeschlagen",
    "(selected)" : "(ausgewählt)",
    "List of files and folders." : "Liste der Dateien und Ordner.",
    "You have used your space quota and cannot upload files anymore." : "Ihr Speicherplatzkontigent ist aufgebraucht, Sie können keine weiteren Dateien hochladen.",
    "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
    "File not found" : "Datei nicht gefunden",
    "_{count} selected_::_{count} selected_" : ["{count} ausgewählt","{count} ausgewählt"],
    "Search everywhere …" : "Überall suchen …",
    "Search here …" : "Hier suchen …",
    "Search scope options" : "Suchbereichsoptionen",
    "Search here" : "Hier suchen",
    "Owner" : "Besitzer",
    "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
    "{used} of {quota} used" : "{used} von {quota} verwendet",
    "{relative}% used" : "{relative} % verwendet",
    "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
    "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage information" : "Speicherinformation",
    "Storage quota" : "Speicherkontingent",
    "New folder" : "Neuer Ordner",
    "Create new folder" : "Neuen Ordner erstellen",
    "This name is already in use." : "Dieser Name wird bereits verwendet.",
    "Create" : "Erstellen",
    "Files starting with a dot are hidden by default" : "Dateien, die mit einem Punkt beginnen, sind standardmäßig ausgeblendet",
    "Failed to start filename sanitization." : "Dateinamenbereinigung konnte nicht gestartet werden.",
    "Failed to refresh filename sanitization status." : "Der Status der Dateinamenbereinigung konnte nicht aktualisiert werden.",
    "Filename sanitization in progress." : "Dateinamenbereinigung läuft.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Es wurden bereits {processedUsers} von {totalUsers} Konten bearbeitet.",
    "Preparing …" : "Bereite vor …",
    "Refresh" : "Aktualisieren",
    "All files have been santized for Windows filename support." : "Alle Dateien wurden für die Windows-Dateinamenunterstützung bereinigt.",
    "Some files could not be sanitized, please check your logs." : "Einige Dateien konnten nicht bereinigt werden. Bitte überprüfen Sie Ihre Protokolle.",
    "Sanitization errors" : "Bereinigungsfehler",
    "Not sanitized filenames" : "Nicht bereinigte Dateinamen",
    "Windows filename support has been enabled." : "Windows Dateinamenunterstützung wurde aktiviert.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Dies hindert Benutzer zwar daran, neue Dateien mit nicht unterstützten Dateinamen zu erstellen, vorhandene Dateien werden jedoch noch nicht umbenannt und können daher unter Windows immer noch die Synchronisierung behindern.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Sie können eine Umbenennung von Dateien mit ungültigen Dateinamen starten. Dies geschieht im Hintergrund und kann einige Zeit dauern.",
    "Please note that this may cause high workload on the sync clients." : "Bitte beachten, dass dies zu einer hohen Auslastung der Synchronisierungsclients führen kann.",
    "Limit" : "Limit",
    "This allows to configure how many users should be processed in one background job run." : "Dadurch kann konfiguriert werden, wie viele Benutzer in einem Hintergrundjoblauf verarbeitet werden.",
    "Sanitize filenames" : "Dateinamen bereinigen",
    "(starting)" : "(Starte)",
    "Fill template fields" : "Vorlagenfelder ausfüllen",
    "Submitting fields …" : "Felder werden übermittelt …",
    "Submit" : "Übermitteln",
    "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Transfer" : "Übertragen",
    "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
    "Invalid path selected" : "Ungültiger Pfad ausgewählt",
    "Unknown error" : "Unbekannter Fehler",
    "Ownership transfer request sent" : "Anforderung für die Besitzübertragung versendet",
    "Cannot transfer ownership of a file or folder you do not own" : "Sie können den Besitz von Dateien oder Ordnern, die Sie nicht besitzen, nicht übertragen",
    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Change" : "Ändern",
    "New owner" : "Neuer Besitzer",
    "Keep {old}" : "{old} behalten",
    "Keep without extension" : "Ohne Erweiterung behalten",
    "Use {new}" : "{new} verwenden",
    "Remove extension" : "Dateierweiterung entfernen",
    "Change file extension" : "Dateierweiterungen ändern",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Ändern der Dateierweiterung von \"{old}\" zu \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Entfernen der Dateierweiterung \"{old}\" kann dazu führen, dass die Datei unlesbar wird.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Hinzufügen der Dateierweiterung \"{new}\" kann dazu führen, dass die Datei unlesbar wird.",
    "Do not show this dialog again." : "Diesen Dialog nicht mehr anzeigen.",
    "Rename file to hidden" : "Datei in versteckt umbenennen",
    "Prefixing a filename with a dot may render the file hidden." : "Das Voranstellen eines Punkts vor einen Dateinamen kann dazu führen, dass die Datei ausgeblendet wird.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "Soll die Datei in \"{filename}\" umbenannt werden?",
    "Cancel" : "Abbrechen",
    "Rename" : "Umbenennen",
    "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
    "Choose {file}" : "{file} auswählen",
    "Files settings" : "Dateien-Einstellungen",
    "Switch to list view" : "Zur Listenansicht wechseln",
    "Switch to grid view" : "Zur Kachelansicht wechseln",
    "The file could not be found" : "Die Datei konnte nicht gefunden werden",
    "Upload was cancelled by user" : "Das Hochladen wurde vom Benutzer abgebrochen",
    "Not enough free space" : "Nicht genügend freier Speicherplatz",
    "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
    "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
    "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
    "Unknown error during upload" : "Unbekannter Fehler beim Hochladen",
    "File list is reloading" : "Dateiliste wird neu geladen",
    "Loading current folder" : "Lade aktuellen Ordner",
    "Retry" : "Wiederholen",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie Ihre Geräte!",
    "Go back" : "Zurückgehen",
    "Views" : "Ansichten",
    "Loading …" : "Lade …",
    "Your files" : "Ihre Dateien",
    "Open in files" : "In Dateien öffnen",
    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Sie haben keine Berechtigungen, um sie anzuzeigen. Bitten Sie den Absender, die Datei zu teilen.",
    "No search results for “{query}”" : "Keine Suchergebnisse für \"{query}\"",
    "Search for files" : "Nach Dateien suchen",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
    "Failed to toggle Windows filename support" : "Windows Dateinamenunterstützung konnte nicht umgeschaltet werden",
    "Files compatibility" : "Dateikompatibilität",
    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
    "Blank" : "Leer",
    "Unable to create new file from template" : "Neue Datei kann nicht aus Vorlage erstellt werden",
    "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
    "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
    "Creating file" : "Datei erstellen",
    "Save as {displayName}" : "Speichern als {displayName}",
    "Save as …" : "Speichern als …",
    "Converting files …" : "Dateien werden konvertiert …",
    "Failed to convert files: {message}" : "Fehler beim Konvertieren der Dateien: {message}",
    "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
    "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
    "_%n file converted_::_%n files converted_" : ["%n Datei konvertiert","%n Dateien konvertiert"],
    "Files converted" : "Dateien konvertiert",
    "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
    "Converting file …" : "Datei wird konvertiert …",
    "File successfully converted" : "Datei konvertiert",
    "Failed to convert file: {message}" : "Fehler beim Konvertieren der Datei: {message}",
    "Failed to convert file" : "Datei konnte nicht konvertiert werden",
    "Delete" : "Löschen",
    "Leave this share" : "Diese Freigabe verlassen",
    "Leave these shares" : "Diese Freigaben verlassen",
    "Disconnect storage" : "Speicher trennen",
    "Disconnect storages" : "Speicher trennen",
    "Delete permanently" : "Endgültig löschen",
    "Delete and unshare" : "Löschen und nicht mehr teilen",
    "Delete file" : "Datei löschen",
    "Delete files" : "Dateien löschen",
    "Delete folder" : "Ordner löschen",
    "Delete folders" : "Ordner löschen",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Sie sind dabei, {count} Elemente endgültig zu löschen"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Sie sind dabei, {count} Elemente zu löschen"],
    "Confirm deletion" : "Löschen bestätigen",
    "Download" : "Herunterladen",
    "The requested file is not available." : "Die angeforderte Datei ist nicht verfügbar.",
    "The requested files are not available." : "Die angeforderten Dateien sind nicht verfügbar.",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
    "Move" : "Verschieben",
    "Copy" : "Kopieren",
    "Move or copy" : "Verschieben oder kopieren",
    "Destination is not a folder" : "Ziel ist kein Ordner",
    "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden",
    "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
    "The files are locked" : "Die Dateien sind gesperrt",
    "The file does not exist anymore" : "Diese Datei existiert nicht mehr",
    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
    "Moving {count} files to \"{destination}\" …" : "Verschiebe {count} Dateien nach \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
    "Copying {count} files to \"{destination}\" …" : "Kopiere {count} Dateien nach \"{destination}\" …",
    "Choose destination" : "Ziel wählen",
    "Copy to {target}" : "Nach {target} kopieren",
    "Move to {target}" : "Nach {target} verschieben",
    "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
    "Open folder" : "Ordner öffnen",
    "Open folder {displayName}" : "Ordner {displayName} öffnen",
    "Open in Files" : "In Dateien öffnen",
    "Open locally" : "Lokal öffnen",
    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
    "Open file locally" : "Datei lokal öffnen",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf Ihrem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfen Sie, ob Sie die Desktop-App installiert haben.",
    "Retry and close" : "Erneut versuchen und schließen",
    "Open online" : "Online öffnen",
    "Details" : "Details",
    "Open the details sidebar" : "Die Details-Seitenleiste öffnen",
    "Unfavorite" : "Nicht favorisieren",
    "View in folder" : "In Ordner anzeigen",
    "Type" : "Typ",
    "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
    "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
    "Create templates folder" : "Vorlagenordner erstellen",
    "Templates" : "Vorlagen",
    "New template folder" : "Neuer Vorlagenordner",
    "In folder" : "Im Ordner",
    "Pick folder to search in" : "Ordner auswählen, in dem gesucht werden soll",
    "Search in all files" : "In allen Dateien suchen",
    "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
    "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ihr Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen",
    "No files to upload" : "Keine Dateien zum Hochladen",
    "Unable to create the directory {directory}" : "Der Ordner {directory} konnte nicht erstellt werden",
    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden.",
    "Files uploaded successfully" : "Dateien hochgeladen",
    "No files to process" : "Keine Dateien zum Verarbeiten",
    "Files copied successfully" : "Dateien kopiert",
    "Files moved successfully" : "Dateien verschoben",
    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden",
    "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
    "Upload cancelled" : "Hochladen abgebrochen",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}\" wird bereits im Ordner \"{dir}\" verwendet. Bitte einen anderen Namen wählen.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This folder is unavailable, please try again later or contact the administration" : "Dieser Ordner ist nicht verfügbar. Bitte später erneut versuchen oder an die Administration wenden",
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Unexpected error: {error}" : "Unerwarteter Fehler: {error}",
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n hidden_::_%n hidden_" : ["%n versteckt","%n versteckt"],
    "Filename must not be empty." : "Dateiname darf nicht leer sein.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ist innerhalb eines Dateinamens nicht zulässig.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ist kein zulässiger Dateityp.",
    "Filenames must not end with \"{extension}\"." : "Dateinamen dürfen nicht mit \"{extension}\" enden.",
    "List of favorite files and folders." : "Liste der favorisierten Ordner und Dateien.",
    "No favorites yet" : "Noch keine Favoriten vorhanden",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
    "List of your files and folders." : "Liste Ihrer Dateien und Ordner.",
    "Folder tree" : "Ordnerbaum",
    "List of your files and folders that are not shared." : "Liste Ihrer Dateien und Ordner, die nicht geteilt wurden.",
    "No personal files found" : "Keine persönlichen Dateien gefunden",
    "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
    "Recent" : "Neueste",
    "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner.",
    "No recently modified files" : "Keine kürzlich geänderten Dateien",
    "Files and folders you recently modified will show up here." : "Die von Ihnen kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
    "Search" : "Suche",
    "Search results within your files." : "Suchergebnisse innerhalb Ihrer Dateien.",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "%1$s (renamed)" : "%1$s (umbenannt)",
    "renamed file" : "Umbenannte Datei",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum Befehl \"occ\".",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
    "Clear filter" : "Filter zurücksetzen",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" ausgeführt",
    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
    "Submitting fields …" : "Felder werden übermittelt …",
    "Shared by link" : "Über einen Link geteilt",
    "Shared" : "Geteilt",
    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" ausgeführt",
    "Filter file names …" : "Dateinamen filtern …",
    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
    "Enable the grid view" : "Kachelansicht aktivieren",
    "Enable folder tree" : "Ordnerstruktur aktivieren",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Use this address to access your Files via WebDAV" : "Benutzen Sie diese Adresse, um via WebDAV auf Ihre Dateien zuzugreifen.",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn Sie 2FA aktiviert haben, müssen Sie ein neues App-Passwort erstellen und verwenden, indem Sie hier klicken.",
    "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
    "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "Speed up your Files experience with these quick shortcuts." : "Arbeiten Sie schneller mit Dateien mit diesen Schnellzugriffen.",
    "Open the actions menu for a file" : "Aktionsmenü für eine Datei öffnen",
    "Rename a file" : "Eine Datei umbenennen",
    "Delete a file" : "Eine Datei löschen",
    "Favorite or remove a file from favorites" : "Datei favorisieren oder aus den Favoriten entfernen",
    "Manage tags for a file" : "Schlagworte für eine Datei verwalten",
    "Deselect all files" : "Auswahl aller Dateien aufheben",
    "Select or deselect a file" : "Auswählen oder Auswahl einer Datei aufheben",
    "Select a range of files" : "Einen Bereich von Dateien auswählen",
    "Navigate to the parent folder" : "Zum übergeordneten Ordner navigieren",
    "Navigate to the file above" : "Zur obigen Datei navigieren",
    "Navigate to the file below" : "Zur unteren Datei navigieren",
    "Navigate to the file on the left (in grid mode)" : "Zur Datei links navigieren (in der Kachelansicht)",
    "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (in der Kachelansicht)",
    "Toggle the grid view" : "Kachelansicht umschalten",
    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
    "You" : "Sie",
    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
    "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
    "Tags" : "Schlagworte",
    "Save as …" : "Speichern als …",
    "Converting files …" : "Dateien werden konvertiert …",
    "Converting file …" : "Datei wird konvertiert …",
    "Deletion cancelled" : "Löschen abgebrochen",
    "Edit locally" : "Lokal bearbeiten",
    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
    "(copy)" : "(Kopie)",
    "(copy %n)" : "(Kopie %n)",
    "Move cancelled" : "Verschieben abgebrochen",
    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
    "Open details" : "Details öffnen",
    "Photos and images" : "Fotos und Bilder",
    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Protokolldateien oder kontaktieren Sie die Administration",
    "All folders" : "Alle Ordner",
    "Open file sidebar" : "Datei-Seitenleiste öffnen",
    "Search everywhere …" : "Überall suchen …",
    "Search here …" : "Hier suchen …",
    "Preparing …" : "Bereite vor …"
},
"nplurals=2; plural=(n != 1);");
